import { world } from "@minecraft/server";
// Nahuel505
// Configuración de la plantilla
const CONFIG = {
    triggerBlocks: ["minecraft:lit_pumpkin", "minecraft:carved_pumpkin"], // Lista de bloques desencadenantes
    targetBlocks: ["minecraft:oak_planks","minecraft:dark_oak_planks","minecraft:birch_planks","minecraft:acacia_planks","minecraft:jungle_planks","minecraft:spruce_planks","minecraft:mangrove_planks","minecraft:cherry_planks","minecraft:bamboo_planks"], // Lista de bloques objetivo
    entityToSpawn: "golems:plank_golem",
    spawnEvent: "minecraft:from_player" // Evento de generación
};

// Función para verificar si un bloque es de uno de los tipos especificados
function isTargetBlock(block, targetBlocks) {
    return block && targetBlocks.includes(block.typeId);
}

// Función para destruir un bloque usando /setblock destroy
function destroyBlock(block, dimension) {
    if (block) {
        const location = block.location;
        dimension.runCommand(`setblock ${location.x} ${location.y} ${location.z} air destroy`);
        // Eliminar ítems en la posición del bloque
        dimension.runCommand(`kill @e[type=item,x=${location.x},y=${location.y},z=${location.z},dx=0,dy=0,dz=0]`);
    }
}

// Función para generar una entidad con un evento de generación
function spawnEntity(entityType, location, dimension, spawnEvent) {
    const entity = dimension.spawnEntity(entityType, location);
    if (entity) {
        entity.triggerEvent(spawnEvent);
    }
}

// Evento que se activa cuando un jugador coloca un bloque
world.afterEvents.playerPlaceBlock.subscribe(e => {
    if (!CONFIG.triggerBlocks.includes(e.block.typeId)) return;
    
    let center_block = e.block.below();
    if (!center_block) return;
    
    let center = isTargetBlock(center_block, "minecraft:target");
    let below = isTargetBlock(center_block.below(), CONFIG.targetBlocks);
    
    if (center && below) {
        spawnEntity(CONFIG.entityToSpawn, center_block.below().location, e.dimension, CONFIG.spawnEvent);    
        destroyBlock(center_block.above(), e.dimension);
        destroyBlock(center_block, e.dimension);
        destroyBlock(center_block.below(), e.dimension);
    }
});